<template>
  <win-sm :title="setting.title" @close="close">
    <el-form :model="formData" ref="ruleForm" :rules="rules" label-width="100px">
      <el-form-item v-for="(c,j) in totalList" :label="'第'+(j+1)+'次投资'">
        <div class="font-14 color-333">
          {{c.releaseInvest}}万元
        </div>
      </el-form-item>
      <el-form-item prop="releaseInvest" :label="'第'+(totalList.length+1)+'次投资'">
        <el-input type="number" v-model="formData.releaseInvest" auto-complete="off">
          <template slot="append">万元</template>
        </el-input>
      </el-form-item>
      <el-form-item prop="releaseTime" label="下达时间">
        <el-date-picker
          v-model="formData.releaseTime"
          type="date"
          format="yyyy-MM-dd"
          value-format="yyyy-MM-dd"
          placeholder="请选择下达时间">
        </el-date-picker>
      </el-form-item>
    </el-form>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close" />
      <my-button name="保存" site="form" @click="save" />
    </div>
  </win-sm>
</template>

<script>
import winSm from '@/components/win/win-sm'
import myButton from "@/components/myButton/myButton";
import * as information from '@/api/projectManage/information'
export default {
  name: "warningSetting",
  components: { winSm, myButton},
  props: {
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      totalList:[],
      formData:{
        releaseInvest:'',
        releaseTime:''
      },
      rules: {
        releaseInvest: [
          { required: true, message: '请输入投资金额', trigger: 'blur' },
          { min: 0, message: '最低不小于0', trigger: 'blur' },
        ],
        releaseTime: [
          { required: true, message: '请选择下达时间', trigger: 'change' }
        ]
      }
    }
  },
  created() {
    this.investInfoList()
  },
  methods:{
    investInfoList(){
      information.getInvestInfoList({id:this.setting.id}).then(res=>{
        this.totalList = res
      })
    },
    close(){
      this.$emit('close')
    },
    save(){
      this.$refs['ruleForm'].validate((valid) => {
        if (valid) {
          let params = Object.assign({},this.formData)
          params.id = this.setting.id
          information.investInfoSave(params).then(res=>{
            this.$message.success('保存成功')
            this.$emit('close')
            this.$emit('search')
          })
        } else {
          return false;
        }
      })
    }
  }
}
</script>

<style scoped>

</style>
